@@ -15,7 +15,7 @@
 #include "noIcon.xpm"
 
 // constructor
-IceIconPreview::IceIconPreview(QWidget *parent=0) : QWidget(parent) {
+IceIconPreview::IceIconPreview(QWidget *parent) : QWidget(parent) {
   setMinimumWidth(60);
   // label for displaying preview pixmap
   label = new QLabel(this);
